@@ -3,19 +3,13 @@
 import os
 import sys
 import json
-import subprocess
 import lizard
+import argparse
+import subprocess
 from shutil import which
 from colorama import init, Fore, Style
 
-
-program = sys.argv[1]
-output = sys.argv[2] if len(sys.argv) == 3 else None
-
-
-filename, extension = os.path.splitext(program)
 bindir = os.path.dirname(os.path.realpath(__file__))
-
 argon_installed = True
 
 # ----------------------------------------------------------------------------
@@ -31,18 +25,18 @@ def check_dependencies():
             missing_list.append(program)
 
     if 'argon' in missing_list:
-        print(Fore.YELLOW + 'Warning: argon is not installed, you will not be able to generate code metrics for Haskell scripts!\n' + Style.RESET_ALL)
+        print(Fore.YELLOW + 'Warning: argon is not installed, you will not be able to generate code metrics for Haskell scripts!\n' + Style.RESET_ALL, file=sys.stderr)
         global argon_installed
         argon_installed = False
         missing_list.remove('argon')
 
     if missing_list:
-        print(Fore.RED + 'The following dependencies are missing, please install them and try again: ', end='')
+        print(Fore.RED + 'The following dependencies are missing, please install them and try again: ', end='', file=sys.stderr)
         for missing_dep in missing_list:
             if missing_dep != missing_list[-1]:
-                print(missing_dep, end=', ')
+                print(missing_dep, end=', ', file=sys.stderr)
             else:
-                print(missing_dep + Style.RESET_ALL)
+                print(missing_dep + Style.RESET_ALL, file=sys.stderr)
         sys.exit(0)
 
 
@@ -51,8 +45,26 @@ def check_dependencies():
 # ----------------------------------------------------------------------------
 
 def main():
+	init()  # Start colorama
 	check_dependencies()
 
+	parser = argparse.ArgumentParser(
+		usage="%(prog)s program",
+		description="Provides measures extracted from a static inspection of the submitted code.",
+	)
+
+	# Parse options with real arguments
+	args = parser.parse_known_args()
+
+	try:
+		program = sys.argv[1]
+	except Exception:
+		print(Fore.RED + 'You must specify a program to analyze it!' + Style.RESET_ALL, file=sys.stderr)
+		sys.exit(0)
+
+	filename, extension = os.path.splitext(program)
+	output = sys.argv[2] if len(sys.argv) == 3 else None
+
 	# count total number of lines
 	lines = len(open(program, "r").readlines())
 
